<?php

namespace Cliente\Cliente\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Cliente\Cliente\Http\Requests\ClienteRequest;
use Cliente\Cliente\Models\Cliente;

/**
 * Admin web controller class.
 */
class ClienteWorkflowController extends BaseController
{

    /**
     * Workflow controller function for cliente.
     *
     * @param Model   $cliente
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ClienteRequest $request, Cliente $cliente, $step)
    {

        try {

            $cliente->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('cliente::cliente.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/cliente/cliente/' . $cliente->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/cliente/cliente/' . $cliente->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for cliente.
     *
     * @param Model   $cliente
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Cliente $cliente, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $cliente->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('cliente::cliente.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('cliente::admin.cliente.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('cliente::admin.cliente.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('cliente::admin.cliente.message', $data)->render();

        }

    }
}
