<?php

namespace Cliente\Cliente\Policies;

use Litepie\User\Contracts\UserPolicy;
use Cliente\Cliente\Models\Cliente;

class ClientePolicy
{

    /**
     * Determine if the given user can view the cliente.
     *
     * @param UserPolicy $user
     * @param Cliente $cliente
     *
     * @return bool
     */
    public function view(UserPolicy $user, Cliente $cliente)
    {
        if ($user->canDo('cliente.cliente.view') && $user->isAdmin()) {
            return true;
        }

        return $cliente->user_id == user_id() && $cliente->user_type == user_type();
    }

    /**
     * Determine if the given user can create a cliente.
     *
     * @param UserPolicy $user
     * @param Cliente $cliente
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('cliente.cliente.create');
    }

    /**
     * Determine if the given user can update the given cliente.
     *
     * @param UserPolicy $user
     * @param Cliente $cliente
     *
     * @return bool
     */
    public function update(UserPolicy $user, Cliente $cliente)
    {
        if ($user->canDo('cliente.cliente.edit') && $user->isAdmin()) {
            return true;
        }

        return $cliente->user_id == user_id() && $cliente->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given cliente.
     *
     * @param UserPolicy $user
     * @param Cliente $cliente
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Cliente $cliente)
    {
        return $cliente->user_id == user_id() && $cliente->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given cliente.
     *
     * @param UserPolicy $user
     * @param Cliente $cliente
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Cliente $cliente)
    {
        if ($user->canDo('cliente.cliente.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given cliente.
     *
     * @param UserPolicy $user
     * @param Cliente $cliente
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Cliente $cliente)
    {
        if ($user->canDo('cliente.cliente.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
