<?php

namespace Cliente\Cliente\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Cliente\Cliente\Models\Cliente;

class ClienteAction
{
    /**
     * Perform the complete action.
     *
     * @param Cliente $cliente
     *
     * @return Cliente
     */
    public function complete(Cliente $cliente)
    {
        try {
            $cliente->status = 'complete';
            return $cliente->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Cliente $cliente
     *
     * @return Cliente
     */public function verify(Cliente $cliente)
    {
        try {
            $cliente->status = 'verify';
            return $cliente->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Cliente $cliente
     *
     * @return Cliente
     */public function approve(Cliente $cliente)
    {
        try {
            $cliente->status = 'approve';
            return $cliente->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Cliente $cliente
     *
     * @return Cliente
     */public function publish(Cliente $cliente)
    {
        try {
            $cliente->status = 'publish';
            return $cliente->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Cliente $cliente
     *
     * @return Cliente
     */
    public function archive(Cliente $cliente)
    {
        try {
            $cliente->status = 'archive';
            return $cliente->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Cliente $cliente
     *
     * @return Cliente
     */
    public function unpublish(Cliente $cliente)
    {
        try {
            $cliente->status = 'unpublish';
            return $cliente->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
