<?php

namespace Cliente\Cliente\Workflow;

use Cliente\Cliente\Models\Cliente;
use Validator;

class ClienteValidator
{

    /**
     * Determine if the given cliente is valid for complete status.
     *
     * @param Cliente $cliente
     *
     * @return bool / Validator
     */
    public function complete(Cliente $cliente)
    {
        return Validator::make($cliente->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given cliente is valid for verify status.
     *
     * @param Cliente $cliente
     *
     * @return bool / Validator
     */
    public function verify(Cliente $cliente)
    {
        return Validator::make($cliente->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given cliente is valid for approve status.
     *
     * @param Cliente $cliente
     *
     * @return bool / Validator
     */
    public function approve(Cliente $cliente)
    {
        return Validator::make($cliente->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given cliente is valid for publish status.
     *
     * @param Cliente $cliente
     *
     * @return bool / Validator
     */
    public function publish(Cliente $cliente)
    {
        return Validator::make($cliente->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given cliente is valid for archive status.
     *
     * @param Cliente $cliente
     *
     * @return bool / Validator
     */
    public function archive(Cliente $cliente)
    {
        return Validator::make($cliente->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given cliente is valid for unpublish status.
     *
     * @param Cliente $cliente
     *
     * @return bool / Validator
     */
    public function unpublish(Cliente $cliente)
    {
        return Validator::make($cliente->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
